pub struct Inventory {
pub readonly: bool,
/* private fields */
}Fields
readonly: boolMakes an inventory read-only for clients. This will prevent adding or removing items. If this is a player inventory This will also make it impossible to drop items while not in the inventory (e.g. by pressing Q)
Implementations
Sourceimpl Inventory
impl Inventory
pub fn new(kind: InventoryKind) -> Self
pub fn with_title<'a, T: IntoText<'a>>(kind: InventoryKind, title: T) -> Self
pub fn slot(&self, idx: u16) -> &ItemStack
Sourcepub fn set_slot<I: Into<ItemStack>>(&mut self, idx: u16, item: I)
pub fn set_slot<I: Into<ItemStack>>(&mut self, idx: u16, item: I)
Sets the slot at the given index to the given item stack.
See also Inventory::replace_slot.
let mut inv = Inventory::new(InventoryKind::Generic9x1);
inv.set_slot(0, ItemStack::new(ItemKind::Diamond, 1));
assert_eq!(inv.slot(0).item, ItemKind::Diamond);Panics
If the slot index is out of bounds.
Sourcepub fn replace_slot<I: Into<ItemStack>>(
&mut self,
idx: u16,
item: I,
) -> ItemStack
pub fn replace_slot<I: Into<ItemStack>>( &mut self, idx: u16, item: I, ) -> ItemStack
Replaces the slot at the given index with the given item stack, and returns the old stack in that slot.
See also Inventory::set_slot.
let mut inv = Inventory::new(InventoryKind::Generic9x1);
inv.set_slot(0, ItemStack::new(ItemKind::Diamond, 1));
let old = inv.replace_slot(0, ItemStack::new(ItemKind::IronIngot, 1));
assert_eq!(old.item, ItemKind::Diamond);Panics
If the slot index is out of bounds.
Sourcepub fn swap_slot(&mut self, idx_a: u16, idx_b: u16)
pub fn swap_slot(&mut self, idx_a: u16, idx_b: u16)
Swap the contents of two slots. If the slots are the same, nothing happens.
let mut inv = Inventory::new(InventoryKind::Generic9x1);
inv.set_slot(0, ItemStack::new(ItemKind::Diamond, 1));
assert!(inv.slot(1).is_empty());
inv.swap_slot(0, 1);
assert_eq!(inv.slot(1).item, ItemKind::Diamond);Panics
If either slot index is out of bounds.
Sourcepub fn set_slot_amount(&mut self, idx: u16, amount: i8)
pub fn set_slot_amount(&mut self, idx: u16, amount: i8)
Set the amount of items in the given slot without replacing the slot
entirely. Valid values are 1-127, inclusive, and amount will be
clamped to this range. If the slot is empty, nothing happens.
let mut inv = Inventory::new(InventoryKind::Generic9x1);
inv.set_slot(0, ItemStack::new(ItemKind::Diamond, 1));
inv.set_slot_amount(0, 64);
assert_eq!(inv.slot(0).count, 64);Panics
If the slot index is out of bounds.
pub fn slot_count(&self) -> u16
pub fn slots( &self, ) -> impl ExactSizeIterator<Item = &ItemStack> + DoubleEndedIterator + FusedIterator + Clone + '_
pub fn kind(&self) -> InventoryKind
Sourcepub fn title(&self) -> &Text
pub fn title(&self) -> &Text
The text displayed on the inventory’s title bar.
let inv = Inventory::with_title(InventoryKind::Generic9x3, "Box of Holding");
assert_eq!(inv.title(), &Text::from("Box of Holding"));Sourcepub fn set_title<'a, T: IntoText<'a>>(&mut self, title: T)
pub fn set_title<'a, T: IntoText<'a>>(&mut self, title: T)
Set the text displayed on the inventory’s title bar.
To get the old title, use Inventory::replace_title.
let mut inv = Inventory::new(InventoryKind::Generic9x3);
inv.set_title("Box of Holding");Sourcepub fn replace_title<'a, T: IntoText<'a>>(&mut self, title: T) -> Text
pub fn replace_title<'a, T: IntoText<'a>>(&mut self, title: T) -> Text
Replace the text displayed on the inventory’s title bar, and returns the old text.
Sourcepub fn first_empty_slot_in(&self, range: Range<u16>) -> Option<u16>
pub fn first_empty_slot_in(&self, range: Range<u16>) -> Option<u16>
Returns the first empty slot in the given range, or None if there are
no empty slots in the range.
let mut inv = Inventory::new(InventoryKind::Generic9x1);
inv.set_slot(0, ItemStack::new(ItemKind::Diamond, 1));
inv.set_slot(2, ItemStack::new(ItemKind::GoldIngot, 1));
inv.set_slot(3, ItemStack::new(ItemKind::IronIngot, 1));
assert_eq!(inv.first_empty_slot_in(0..6), Some(1));
assert_eq!(inv.first_empty_slot_in(2..6), Some(4));Sourcepub fn first_empty_slot(&self) -> Option<u16>
pub fn first_empty_slot(&self) -> Option<u16>
Returns the first empty slot in the inventory, or None if there are no
empty slots.
let mut inv = Inventory::new(InventoryKind::Generic9x1);
inv.set_slot(0, ItemStack::new(ItemKind::Diamond, 1));
inv.set_slot(2, ItemStack::new(ItemKind::GoldIngot, 1));
inv.set_slot(3, ItemStack::new(ItemKind::IronIngot, 1));
assert_eq!(inv.first_empty_slot(), Some(1));Sourcepub fn first_slot_with_item_in(
&self,
item: ItemKind,
stack_max: i8,
range: Range<u16>,
) -> Option<u16>
pub fn first_slot_with_item_in( &self, item: ItemKind, stack_max: i8, range: Range<u16>, ) -> Option<u16>
Returns the first slot with the given ItemKind in the inventory
where count < stack_max, or None if there are no empty slots.
let mut inv = Inventory::new(InventoryKind::Generic9x1);
inv.set_slot(0, ItemStack::new(ItemKind::Diamond, 1));
inv.set_slot(2, ItemStack::new(ItemKind::GoldIngot, 64));
inv.set_slot(3, ItemStack::new(ItemKind::IronIngot, 1));
inv.set_slot(4, ItemStack::new(ItemKind::GoldIngot, 1));
assert_eq!(
inv.first_slot_with_item_in(ItemKind::GoldIngot, 64, 0..5),
Some(4)
);Sourcepub fn first_slot_with_item(&self, item: ItemKind, stack_max: i8) -> Option<u16>
pub fn first_slot_with_item(&self, item: ItemKind, stack_max: i8) -> Option<u16>
Returns the first slot with the given ItemKind in the inventory
where count < stack_max, or None if there are no empty slots.
let mut inv = Inventory::new(InventoryKind::Generic9x1);
inv.set_slot(0, ItemStack::new(ItemKind::Diamond, 1));
inv.set_slot(2, ItemStack::new(ItemKind::GoldIngot, 64));
inv.set_slot(3, ItemStack::new(ItemKind::IronIngot, 1));
inv.set_slot(4, ItemStack::new(ItemKind::GoldIngot, 1));
assert_eq!(inv.first_slot_with_item(ItemKind::GoldIngot, 64), Some(4));Trait Implementations
Sourceimpl Component for Inventory
impl Component for Inventory
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
Sourcetype Mutability = Mutable
type Mutability = Mutable
Component<Mutability = Mutable>],
while immutable components will instead have [Component<Mutability = Immutable>]. Read moreSourcefn register_required_components(
_requiree: ComponentId,
required_components: &mut RequiredComponentsRegistrator<'_, '_>,
)
fn register_required_components( _requiree: ComponentId, required_components: &mut RequiredComponentsRegistrator<'_, '_>, )
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Sourcefn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
fn relationship_accessor() -> Option<ComponentRelationshipAccessor<Self>>
ComponentRelationshipAccessor] required for working with relationships in dynamic contexts. Read morefn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
on_add [ComponentHook] for this [Component] if one is defined.fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
on_insert [ComponentHook] for this [Component] if one is defined.fn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_discard() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
on_discard [ComponentHook] for this [Component] if one is defined.fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
on_remove [ComponentHook] for this [Component] if one is defined.fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
on_despawn [ComponentHook] for this [Component] if one is defined.fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
EntityMapper]. This is used to remap entities in contexts like scenes and entity cloning.
When deriving [Component], this is populated by annotating fields containing entities with #[entities] Read moreAuto Trait Implementations
impl Freeze for Inventory
impl RefUnwindSafe for Inventory
impl Send for Inventory
impl Sync for Inventory
impl Unpin for Inventory
impl UnsafeUnpin for Inventory
impl UnwindSafe for Inventory